User documentation for Coil CMS
===============================

Welcome to Coil CMS!

Coil CMS is a Content Management System.  A Content Management System is used
to administer websites.  Coil is one of many of them on the market.  Coil
offers many benefits over the traditional CMSes to both users and
administrators.  Coil CMS strives to be user-friendly and easy to use.

.. toctree::
   :maxdepth: 2
   :glob:
   :numbered:

   getting-started
   index-page
   edit
   delete
   rebuild
   account
